@@ -188,8 +188,14 @@ farsight_codec_list_copy (const GList *codec_list)
  * [audio/codec2]
  * one_param=QCIF
  * another_param=WOW
+ *
+ * [audio/codec3]
+ * id=-1
  * </programlisting></informalexample>
  *
+ * If "id" is set to a negative value, it means that it will prevent
+ * the system for auto-offering any codec matching the entry
+ *
  * Return value: The read #GList of #FarsightCodec or %NULL if an error appended
  */
 GList *
@@ -230,7 +236,7 @@ farsight_codec_list_from_keyfile (const gchar *filename)
     gchar *encoding_name = NULL;
     gchar *next_tok = NULL;
 
-    codec->id = -1;
+    codec->id = FARSIGHT_CODEC_ID_ANY;
 
     keys = g_key_file_get_keys (keyfile, groups[i], &keys_count, &gerror);
 
@@ -293,10 +299,13 @@ farsight_codec_list_from_keyfile (const gchar *filename)
          codec->id = g_key_file_get_integer (keyfile, groups[i], keys[j],
             &gerror);
         if (gerror) {
-          codec->id = 0;
+          codec->id = FARSIGHT_CODEC_ID_ANY;
           goto keyerror;
         }
 
+        if (codec->id < 0)
+          codec->id = FARSIGHT_CODEC_ID_DISABLE;
+
       } else if (!strcmp ("channels", keys[j])) {
          codec->channels = g_key_file_get_integer (keyfile, groups[i], keys[j],
             &gerror);
@@ -313,7 +322,7 @@ farsight_codec_list_from_keyfile (const gchar *filename)
             &gerror);
         if (gerror) {
           g_free (param->name);
-          g_free (param->name);
+          g_free (param->value);
           g_free (param);
           goto keyerror;
         }
@@ -397,3 +406,72 @@ farsight_codec_to_string (FarsightCodec *codec)
 
   return charstring;
 }
+
+/*
+ * Check if all of the elements of list1 are in list2
+ * It compares GLists of FarsightCodecParameter
+ */
+static gboolean
+compare_lists(GList *list1, GList *list2)
+{
+  GList *item1;
+
+  for (item1 = g_list_first (list1);
+       item1;
+       item1 = g_list_next (item1)) {
+    FarsightCodecParameter *param1 = item1->data;
+    GList *item2 = NULL;
+
+    for (item2 = g_list_first (list2);
+         item2;
+         item2 = g_list_next (item2)) {
+      FarsightCodecParameter *param2 = item2->data;
+
+      if (!strcmp (param1->name, param2->name) &&
+          !strcmp (param1->value, param2->value))
+        break;
+    }
+    if (!item2)
+      return FALSE;
+  }
+
+  return TRUE;
+}
+
+
+/**
+ * farsight_codec_compare
+ * @codec1: First codec
+ * @codec2: Second codec
+ *
+ * Compare two codecs
+ *
+ * Return value: TRUE of the codecs are identical, FALSE otherwise
+ */
+
+gboolean
+farsight_codec_compare (FarsightCodec *codec1, FarsightCodec *codec2)
+{
+  if (codec1 == codec2)
+    return TRUE;
+
+  if (!codec1 || !codec2)
+    return FALSE;
+
+  if (codec1->id != codec2->id ||
+      codec1->media_type != codec2->media_type ||
+      codec1->clock_rate != codec2->clock_rate ||
+      codec1->channels != codec2->channels ||
+      strcmp (codec1->encoding_name, codec2->encoding_name))
+    return FALSE;
+
+
+  /* Is there a smarter way to compare to un-ordered linked lists
+   * to make sure they contain exactly the same elements??
+   */
+  if (!compare_lists (codec1->optional_params, codec2->optional_params) ||
+      !compare_lists (codec2->optional_params, codec1->optional_params))
+    return FALSE;
+
+  return TRUE;
+}
