@@ -46,6 +46,10 @@ typedef enum
   FARSIGHT_MEDIA_TYPE_LAST = FARSIGHT_MEDIA_TYPE_VIDEO
 } FarsightMediaType;
 
+
+#define FARSIGHT_CODEC_ID_ANY            (-1)
+#define FARSIGHT_CODEC_ID_DISABLE        (-2)
+
 /**
  * FarsightCodec:
  * @id: numeric identifier for encoding, eg. PT for SDP
@@ -106,6 +110,8 @@ gchar *farsight_codec_to_string (FarsightCodec *codec);
 
 const gchar *farsight_media_type_to_string (FarsightMediaType media_type);
 
+gboolean farsight_codec_compare (FarsightCodec *codec1, FarsightCodec *codec2);
+
 G_END_DECLS
 #endif
 
