@@ -54,10 +54,10 @@
 /* VOID:INT,INT (./farsight-marshal.list:2) */
 void
 farsight_marshal_VOID__INT_INT (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -91,10 +91,10 @@ farsight_marshal_VOID__INT_INT (GClosure     *closure,
 /* VOID:INT,STRING (./farsight-marshal.list:3) */
 void
 farsight_marshal_VOID__INT_STRING (GClosure     *closure,
-                                   GValue       *return_value,
+                                   GValue       *return_value G_GNUC_UNUSED,
                                    guint         n_param_values,
                                    const GValue *param_values,
-                                   gpointer      invocation_hint,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer     data1,
@@ -128,10 +128,10 @@ farsight_marshal_VOID__INT_STRING (GClosure     *closure,
 /* VOID:STRING,STRING (./farsight-marshal.list:4) */
 void
 farsight_marshal_VOID__STRING_STRING (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
