@@ -630,7 +630,8 @@ farsight_stream_get_codec_intersection (FarsightStream *self)
  * @self: a #FarsightStream
  * @codec_pref: a GArray of #FarsightCodecPreference
  *
- * Set a list of prefered codecs (optional)
+ * Set a list of prefered codecs (optional). Setting it to NULL will unset
+ * the list. A 0-length list is invalid.
  *
  */
 void farsight_stream_set_codec_preference_list (FarsightStream *self,
@@ -702,6 +703,10 @@ farsight_stream_get_active_codec (FarsightStream *self)
  * incoming stream and remove the old sink. If called with a new sink it will
  * replace the old one. If there is a user specified pipeline, the sink won't be
  * added into the Farsight bin.
+ * This function will eat one reference to the element, if you want to keep a
+ * reference, make sure you have a second one.
+ * Any sink set with this function must be be in main pipeline if one has
+ * been set.
  *
  * Returns: %TRUE if sucessful
  */
@@ -754,6 +759,8 @@ farsight_stream_set_sink_filter (FarsightStream *self,
  * @self: a #FarsightStream
  *
  * Get the GStreamer sink for this stream
+ * This function will eat one reference to the element, if you want to keep a
+ * reference, make sure you have a second one.
  *
  * Returns: A #GstElement for the current stream sink
  **/
@@ -781,6 +788,10 @@ farsight_stream_get_sink (FarsightStream *self)
  * Set the GStreamer source for this stream. If the element does not have a
  * parent, it will be added into the Farsight stream bin. So if you need to set
  * a parent for the source, do it before calling this function.
+ * This function will eat one reference to the element, if you want to keep a
+ * reference, make sure you have a second one.
+ * Any source set with this function must be be in main pipeline if one has
+ * been set.
  *
  * Returns: %TRUE if sucessful
  **/
@@ -791,7 +802,6 @@ farsight_stream_set_source (FarsightStream *self,
   FarsightStreamClass *klass = FARSIGHT_STREAM_GET_CLASS (self);
   g_return_val_if_fail (g_type_is_a (G_OBJECT_TYPE (self), FARSIGHT_TYPE_STREAM),
                         FALSE);
-  g_return_val_if_fail (source != NULL, FALSE);
 
   if (klass->set_source) {
     return klass->set_source (self, source);
@@ -943,7 +953,8 @@ GstElement * farsight_stream_get_pipeline (FarsightStream *self)
  * is set by the user, the sources will not be added into the Farsight bin.
  *
  * NOTE: This has to be called before farsight_stream_prepare_transports() in
- * order to be used.
+ * order to be used. It must also be called before any call to
+ * farsight_stream_set_source() and farsight_stream_set_sink().
  *
  * Return value: %TRUE if successful
  *
@@ -1034,6 +1045,85 @@ gboolean farsight_stream_set_sending (FarsightStream *self, gboolean sending)
   return FALSE; // this shouldn't happen
 }
 
+/**
+ * farsight_stream_hold:
+ * @self: a #FarsightStream
+ *
+ * This function will tell Farsight to hold the current call. This will completely destroy
+ * the codec bin and set the source to GST_STATE_NULL in order to free the used resources.
+ *
+ * Note that this function call is blocking and if the pipeline elements can't go to the
+ * NULL state or if the sink blocks indefinitely on a buffer, this function might never
+ * return.
+ *
+ * Return value: %TRUE if successful
+ *
+ */
+gboolean farsight_stream_hold (FarsightStream *self)
+{
+  FarsightStreamClass *klass = FARSIGHT_STREAM_GET_CLASS (self);
+  g_return_val_if_fail (g_type_is_a (G_OBJECT_TYPE (self), 
+        FARSIGHT_TYPE_STREAM), FALSE);
+
+  if (klass->hold) {
+    return klass->hold (self);
+  } else {
+    g_warning ("hold not defined for %s", 
+        G_OBJECT_TYPE_NAME (self));
+  }
+  return FALSE; // this shouldn't happen
+}
+
+/**
+ * farsight_stream_unhold:
+ * @self: a #FarsightStream
+ *
+ * This function will tell Farsight to unhold the current call. This will recreate
+ * the codec bin and set the source back to GST_STATE_PLAYING.
+ *
+ * Return value: %TRUE if successful
+ *
+ */
+gboolean farsight_stream_unhold (FarsightStream *self)
+{
+  FarsightStreamClass *klass = FARSIGHT_STREAM_GET_CLASS (self);
+  g_return_val_if_fail (g_type_is_a (G_OBJECT_TYPE (self), 
+        FARSIGHT_TYPE_STREAM), FALSE);
+
+  if (klass->unhold) {
+    return klass->unhold (self);
+  } else {
+    g_warning ("unhold not defined for %s", 
+        G_OBJECT_TYPE_NAME (self));
+  }
+  return FALSE; // this shouldn't happen
+}
+
+/**
+ * farsight_stream_is_held:
+ * @self: a #FarsightStream
+ *
+ * This function will tell you whether the current call is being hold or not.
+ *
+ * Return value: %TRUE if the call is held
+ *
+ */
+gboolean farsight_stream_is_held (FarsightStream *self)
+{
+  FarsightStreamClass *klass = FARSIGHT_STREAM_GET_CLASS (self);
+  g_return_val_if_fail (g_type_is_a (G_OBJECT_TYPE (self), 
+        FARSIGHT_TYPE_STREAM), FALSE);
+
+  if (klass->is_held) {
+    return klass->is_held (self);
+  } else {
+    g_warning ("is_held not defined for %s", 
+        G_OBJECT_TYPE_NAME (self));
+  }
+  return FALSE; // this shouldn't happen
+}
+
+
 gchar *error_messages[FARSIGHT_STREAM_ERROR_LAST + 1] =
 {
   gettext_noop ("The stream was terminated"),
@@ -1334,7 +1424,8 @@ farsight_stream_stop_telephony_event_full (FarsightStream *self,
  *
  * This function will preload a codec instead of loading it when the first
  * codec arrives. It is particularly useful with DSP and other slow to load
- * and initialise codecs.
+ * and initialise codecs. It must be called after
+ * farsight_stream_set_remote_codecs().
  *
  * Return value: TRUE if sucessful, it can return FALSE if the #FarsightStream
  * is already receiving packets or if the codec can not be preloaded.
@@ -1353,3 +1444,24 @@ gboolean farsight_stream_preload_receive_pipeline (
 
   return FALSE;
 }
+
+
+gboolean farsight_stream_get_jb_statistics (FarsightStream *self,
+                                            guint64 *total_packets,
+                                            guint64 *late_packets,
+                                            guint64 *duplicate_packets,
+                                            guint   *fill_level,
+                                            guint64 *times_overrun,
+                                            guint64 *times_underrun)
+{
+  FarsightStreamClass *klass = FARSIGHT_STREAM_GET_CLASS (self);
+  g_return_val_if_fail (g_type_is_a (G_OBJECT_TYPE (self),
+          FARSIGHT_TYPE_STREAM), FALSE);
+
+  if (klass->get_jb_statistics) {
+    return klass->get_jb_statistics (self, total_packets, late_packets,
+        duplicate_packets, fill_level, times_overrun, times_underrun);
+  }
+
+  return FALSE;
+}
