@@ -53,36 +53,6 @@ typedef struct _FarsightStream FarsightStream;
 typedef struct _FarsightStreamClass FarsightStreamClass;
 typedef struct _FarsightStreamPrivate FarsightStreamPrivate;
 
-/**
- * FarsightCandidateType:
- * @FARSIGHT_CANDIDATE_TYPE_LOCAL: A local address
- * @FARSIGHT_CANDIDATE_TYPE_DERIVED: An address derived by some method such as STUN which should reach the local client
- * @FARSIGHT_CANDIDATE_TYPE_RELAY: An external stream relay
- *
- * An enum for the type of candidate used/reported
- */
-typedef enum
-{
-  FARSIGHT_CANDIDATE_TYPE_LOCAL,   /* A local address */
-  FARSIGHT_CANDIDATE_TYPE_DERIVED, /* An address derived by some method such as 
-                                    * STUN which should reach the local client
-                                    */
-  FARSIGHT_CANDIDATE_TYPE_RELAY    /* An external stream relay */
-} FarsightCandidateType;
-
-/**
- * FarsightNetworkProtocol:
- * @FARSIGHT_NETWORK_PROTOCOL_UDP: A UDP based protocol
- * @FARSIGHT_NETWORK_PROTOCOL_TCP: A TCP based protocol
- *
- * An enum for the base IP protocol used for a #FarsightStream
- */
-typedef enum
-{
-  FARSIGHT_NETWORK_PROTOCOL_UDP,
-  FARSIGHT_NETWORK_PROTOCOL_TCP
-} FarsightNetworkProtocol;
-
 /**
  * FarsightStreamDirection:
  * @FARSIGHT_STREAM_DIRECTION_NONE: No stream direction defined.
@@ -94,10 +64,10 @@ typedef enum
  */
 typedef enum
 {
-  FARSIGHT_STREAM_DIRECTION_NONE,
-  FARSIGHT_STREAM_DIRECTION_SENDONLY,
-  FARSIGHT_STREAM_DIRECTION_RECEIVEONLY,
-  FARSIGHT_STREAM_DIRECTION_BOTH,
+  FARSIGHT_STREAM_DIRECTION_NONE = 0,
+  FARSIGHT_STREAM_DIRECTION_SENDONLY = 1,
+  FARSIGHT_STREAM_DIRECTION_RECEIVEONLY = 2,
+  FARSIGHT_STREAM_DIRECTION_BOTH = 3,
   FARSIGHT_STREAM_DIRECTION_LAST
 } FarsightStreamDirection;
 
@@ -144,6 +114,52 @@ typedef enum
   FARSIGHT_STREAM_ERROR_LAST = FARSIGHT_STREAM_ERROR_RESOURCE
 } FarsightStreamError;
 
+/**
+ * FarsightStreamDTMFEvent:
+ *
+ * An enum that represents the different DTMF event that can be sent to a
+ * #FarsightStream. The values corresponds those those defined in RFC 4733
+ * The rest of the possibles values are in the IANA registry at:
+ * http://www.iana.org/assignments/audio-telephone-event-registry
+ *
+ */
+typedef enum
+{
+  FARSIGHT_DTMF_EVENT_0 = 0,
+  FARSIGHT_DTMF_EVENT_1 = 1,
+  FARSIGHT_DTMF_EVENT_2 = 2,
+  FARSIGHT_DTMF_EVENT_3 = 3,
+  FARSIGHT_DTMF_EVENT_4 = 4,
+  FARSIGHT_DTMF_EVENT_5 = 5,
+  FARSIGHT_DTMF_EVENT_6 = 6,
+  FARSIGHT_DTMF_EVENT_7 = 7,
+  FARSIGHT_DTMF_EVENT_8 = 8,
+  FARSIGHT_DTMF_EVENT_9 = 9,
+  FARSIGHT_DTMF_EVENT_STAR = 10,
+  FARSIGHT_DTMF_EVENT_POUND = 11,
+  FARSIGHT_DTMF_EVENT_A = 12,
+  FARSIGHT_DTMF_EVENT_B = 13,
+  FARSIGHT_DTMF_EVENT_C = 14,
+  FARSIGHT_DTMF_EVENT_D = 15
+} FarsightStreamDTMFEvent;
+
+
+/**
+ * FarsightStreamDTMFMethod:
+ * @FARSIGHT_DTMF_METHOD_AUTO: Send in any possible way
+ * @FARSIGHT_DTMF_METHOD_RTP_RFC4733: Send as a special payload type defined by RFC 4733 
+ * (which obsoletes RFC 2833)
+ * @FARSIGHT_DTMF_METHOD_SOUND: Send as sound
+ *
+ * An enum that represents the different ways a DTMF event can be sent
+ */
+typedef enum
+{
+  FARSIGHT_DTMF_METHOD_AUTO = 0,
+  FARSIGHT_DTMF_METHOD_RTP_RFC4733,
+  FARSIGHT_DTMF_METHOD_SOUND
+} FarsightStreamDTMFMethod;
+
 struct _FarsightStreamClass
 {
   GObjectClass parent_class;
@@ -167,11 +183,11 @@ struct _FarsightStreamClass
 
   /* void (*set_local_codec_selection) (FarsightStream *self, const GList *ids); */
   G_CONST_RETURN GList * (* get_local_codecs) (FarsightStream *self);
-  void (* set_remote_codecs) (FarsightStream *self, 
+  gboolean (* set_remote_codecs) (FarsightStream *self,
                               const GList *codecs);
   GList *(* get_codec_intersection) (FarsightStream *self);
   void (* set_codec_preference_list) (FarsightStream *self,
-          FarsightCodecPreference codec_pref[]);
+          const GArray *codec_pref);
   void (* set_active_codec) (FarsightStream *self, 
                              gint id);
   gint (* get_active_codec) (FarsightStream *self);
@@ -188,8 +204,27 @@ struct _FarsightStreamClass
   gboolean (* start) (FarsightStream *self);
   void (* stop) (FarsightStream *self);
   gboolean (*set_sending) (FarsightStream *self, gboolean sending);
+  gboolean (*hold) (FarsightStream *self);
+  gboolean (*unhold) (FarsightStream *self);
+  gboolean (*is_held) (FarsightStream *self);
+  
+  gboolean (* start_telephony_event) (FarsightStream *self, 
+                                      guint8 ev,
+                                      guint8 volume,
+                                      FarsightStreamDTMFMethod method);
+  gboolean (* stop_telephony_event) (FarsightStream *self,
+                                     FarsightStreamDTMFMethod method);
 
-  gpointer _padding[4];         /* padding for binary-compatible expansion */
+  gboolean (*preload_receive_pipeline) (FarsightStream *self,
+                                        gint payload_type);
+
+  gboolean (* get_jb_statistics) (FarsightStream *self,
+                                  guint64 *total_packets,
+                                  guint64 *late_packets,
+                                  guint64 *duplicate_packets,
+                                  guint   *fill_level,
+                                  guint64 *times_overrun,
+                                  guint64 *times_underrun);
 };
 
 /**
@@ -230,14 +265,14 @@ gboolean farsight_stream_set_active_candidate_pair (FarsightStream *self,
                                           const GList *ids); */
 G_CONST_RETURN GList *farsight_stream_get_local_codecs (FarsightStream *self);
 
-void farsight_stream_set_remote_codecs (FarsightStream *self,
+gboolean farsight_stream_set_remote_codecs (FarsightStream *self,
                                         const GList *codecs);
 /* G_CONST_RETURN GList *farsight_stream_get_remote_codecs (FarsightStream *self); */
 
 GList *farsight_stream_get_codec_intersection (FarsightStream *self);
 
 void farsight_stream_set_codec_preference_list (FarsightStream *self,
-        FarsightCodecPreference codec_pref[]);
+        const GArray *codec_pref);
 
 void farsight_stream_set_active_codec (FarsightStream *self, 
                                        gint id);
@@ -259,6 +294,7 @@ gboolean farsight_stream_set_source_filter (FarsightStream *self, GstCaps *filte
 
 FarsightStreamState farsight_stream_get_state (FarsightStream *self);
 FarsightStreamDirection farsight_stream_get_direction (FarsightStream *self);
+FarsightStreamDirection farsight_stream_get_current_direction (FarsightStream *self);
 FarsightMediaType farsight_stream_get_media_type (FarsightStream *self);
 GstElement * farsight_stream_get_pipeline (FarsightStream *self);
 gboolean farsight_stream_set_pipeline (FarsightStream *self,
@@ -268,6 +304,10 @@ gboolean farsight_stream_start (FarsightStream *self);
 void farsight_stream_stop (FarsightStream *self);
 gboolean farsight_stream_set_sending (FarsightStream *self, gboolean sending);
 
+gboolean farsight_stream_hold (FarsightStream *self);
+gboolean farsight_stream_unhold (FarsightStream *self);
+gboolean farsight_stream_is_held (FarsightStream *self);
+
 /* Signals */
 void farsight_stream_signal_error (FarsightStream *self, 
                                    FarsightStreamError err,
@@ -283,6 +323,34 @@ void farsight_stream_signal_codec_changed (FarsightStream *self,
 void farsight_stream_signal_state_changed (FarsightStream *self,
                                            FarsightStreamState state,
                                            FarsightStreamDirection direction);
+void farsight_stream_signal_sink_pad_ready (FarsightStream *self,
+                                            GstPad *pad);
+
+gboolean farsight_stream_start_telephony_event (FarsightStream *self, 
+                                                guint8 ev,
+                                                guint8 volume);
+
+gboolean farsight_stream_stop_telephony_event (FarsightStream *self);
+
+gboolean farsight_stream_start_telephony_event_full (FarsightStream *self,
+                                                     guint8 ev,
+                                                     guint8 volume,
+                                                     FarsightStreamDTMFMethod method);
+
+gboolean farsight_stream_stop_telephony_event_full (FarsightStream *self,
+                                                    FarsightStreamDTMFMethod method);
+
+gboolean farsight_stream_preload_receive_pipeline (
+    FarsightStream *self, gint payload_type);
+
+gboolean farsight_stream_get_jb_statistics (FarsightStream *self,
+                                            guint64 *total_packets,
+                                            guint64 *late_packets,
+                                            guint64 *duplicate_packets,
+                                            guint   *fill_level,
+                                            guint64 *times_overrun,
+                                            guint64 *times_underrun);
+
 
 G_END_DECLS
 #endif
