@@ -21,17 +21,23 @@
 
 #include "farsight-interfaces.h"
 
-#ifdef G_OS_UNIX 
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+
+#ifdef G_OS_UNIX
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include <errno.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
-#if defined(__APPLE__) && defined(__MACH__)
+#ifdef HAVE_GETIFADDRS
 #include <sys/socket.h>
+#include <ifaddrs.h>
 #endif
 #include <net/if.h>
 #include <net/if_arp.h>
@@ -44,12 +50,40 @@
  *
  * Returns: a #GList of strings.
  */
+#ifdef HAVE_GETIFADDRS
 GList * farsight_get_local_interfaces() {
+  GList *interfaces = NULL;
+  struct ifaddrs *ifa, *results;
+
+  if (getifaddrs(&results) < 0) {
+    return NULL;
+  }
+
+  /* Loop and get each interface the system has, one by one... */
+  for (ifa = results; ifa; ifa = ifa->ifa_next) {
+    /* no ip address from interface that is down */
+    if ((ifa->ifa_flags & IFF_UP) == 0)
+          continue;
+
+    if (ifa->ifa_addr == NULL || ifa->ifa_addr->sa_family != AF_INET)
+      continue;
+
+    g_debug("Found interface : %s", ifa->ifa_name);
+    interfaces = g_list_prepend(interfaces, g_strdup(ifa->ifa_name));
+  }
+
+  freeifaddrs (results);
+
+  return interfaces;
+}
+
+#else
+GList * farsight_get_local_interfaces() {
+  GList *interfaces = NULL;
   gint sockfd;
   gint size = 0;
   struct ifreq *ifr;
   struct ifconf ifc;
-  GList *interfaces = NULL;
 
   if (0 > (sockfd = socket(AF_INET, SOCK_DGRAM, IPPROTO_IP))) {
     g_warning("Cannot open socket to retreive interface list");
@@ -58,7 +92,7 @@ GList * farsight_get_local_interfaces() {
 
   ifc.ifc_len = 0;
   ifc.ifc_req = NULL;
-  
+
   /* Loop and get each interface the system has, one by one... */
   do {
     size += sizeof(struct ifreq);
@@ -77,7 +111,7 @@ GList * farsight_get_local_interfaces() {
     }
   } while  (size <= ifc.ifc_len);
 
-  
+
   /* Loop throught the interface list and get the IP address of each IF */
   for (ifr = ifc.ifc_req;(gchar *) ifr < (gchar *) ifc.ifc_req + ifc.ifc_len; ++ifr) {
     g_debug("Found interface : %s", ifr->ifr_name);
@@ -88,6 +122,7 @@ GList * farsight_get_local_interfaces() {
 
   return interfaces;
 }
+#endif
 
 
 static gboolean farsight_is_private_ip (const struct in_addr in)
@@ -116,14 +151,57 @@ static gboolean farsight_is_private_ip (const struct in_addr in)
  *
  * Returns: A #GList of strings
  */
+#ifdef HAVE_GETIFADDRS
 GList * farsight_get_local_ips(gboolean include_loopback)
 {
+  GList *ips = NULL;
+  struct sockaddr_in *sa;
+  struct ifaddrs *ifa, *results;
+
+
+  if (getifaddrs(&results) < 0) {
+    return NULL;
+  }
+
+  /* Loop through the interface list and get the IP address of each IF */
+  for (ifa = results; ifa; ifa = ifa->ifa_next) {
+    /* no ip address from interface that is down */
+    if ((ifa->ifa_flags & IFF_UP) == 0)
+          continue;
+
+    if (ifa->ifa_addr == NULL || ifa->ifa_addr->sa_family != AF_INET)
+      continue;
+
+    sa = (struct sockaddr_in *) ifa->ifa_addr;
+
+    g_debug("Interface:  %s", ifa->ifa_name);
+    g_debug("IP Address: %s", inet_ntoa(sa->sin_addr));
+    if ( !include_loopback && (ifa->ifa_flags & IFF_LOOPBACK) == IFF_LOOPBACK) {
+      g_debug("Ignoring loopback interface");
+    } else {
+      if (farsight_is_private_ip (sa->sin_addr)) {
+        ips = g_list_append(ips, g_strdup(inet_ntoa(sa->sin_addr)));
+      } else {
+        ips = g_list_prepend(ips, g_strdup(inet_ntoa(sa->sin_addr)));
+      }
+    }
+  }
+
+  freeifaddrs (results);
+
+  return ips;
+}
+
+#else
+
+GList * farsight_get_local_ips(gboolean include_loopback)
+{
+  GList *ips = NULL;
   gint sockfd;
   gint size = 0;
   struct ifreq *ifr;
   struct ifconf ifc;
   struct sockaddr_in *sa;
-  GList *ips = NULL;
 
   if (0 > (sockfd = socket(AF_INET, SOCK_DGRAM, IPPROTO_IP))) {
     g_warning("Cannot open socket to retreive interface list");
@@ -132,7 +210,7 @@ GList * farsight_get_local_ips(gboolean include_loopback)
 
   ifc.ifc_len = 0;
   ifc.ifc_req = NULL;
-  
+
   /* Loop and get each interface the system has, one by one... */
   do {
     size += sizeof(struct ifreq);
@@ -151,7 +229,7 @@ GList * farsight_get_local_ips(gboolean include_loopback)
     }
   } while  (size <= ifc.ifc_len);
 
-  
+
   /* Loop throught the interface list and get the IP address of each IF */
   for (ifr = ifc.ifc_req;(gchar *) ifr < (gchar *) ifc.ifc_req + ifc.ifc_len; ++ifr) {
 
@@ -177,6 +255,8 @@ GList * farsight_get_local_ips(gboolean include_loopback)
 
   return ips;
 }
+#endif
+
 
 /**
  * farsight_get_ip_for_interface:
@@ -211,7 +291,6 @@ gchar * farsight_get_ip_for_interface(gchar *interface_name) {
   sa = (struct sockaddr_in *) &ifr.ifr_addr;
   g_debug("Address for %s: %s", interface_name, inet_ntoa(sa->sin_addr));
   return inet_ntoa(sa->sin_addr);
-  
 }
 
 #else /* G_OS_UNIX */
@@ -222,6 +301,8 @@ gchar * farsight_get_ip_for_interface(gchar *interface_name) {
 
 static gboolean started_wsa_engine = FALSE;
 
+#error Windows support is not yet implemented
+
 /**
  * private function that initializes the WinSock engine and returns a prebuilt socket
  **/
@@ -231,10 +312,10 @@ SOCKET farsight_get_WSA_socket() {
   WSADATA wsaData;
   int err;
   SOCKET sock;
-  
-  if (started_wsa_engine == FALSE) { 
+
+  if (started_wsa_engine == FALSE) {
     wVersionRequested = MAKEWORD( 2, 0 );
-    
+
     err = WSAStartup( wVersionRequested, &wsaData );
     if ( err != 0 ) {
       g_warning("Could not start the winsocket engine");
@@ -248,14 +329,14 @@ SOCKET farsight_get_WSA_socket() {
     g_warning("Could not open socket to retreive interface list, error no : %d", WSAGetLastError());
     return INVALID_SOCKET;
   }
-  
+
   return sock;
 }
 
 /**
  * Returns the list of local interfaces
  **/
-GList * farsight_get_local_interfaces() 
+GList * farsight_get_local_interfaces()
 {
   return NULL;
 }
@@ -272,7 +353,7 @@ GList * farsight_get_local_ips()
 /**
  * retreives the IP Address of an interface by its name
  **/
-gchar * farsight_get_ip_for_interface(gchar *interface_name) 
+gchar * farsight_get_ip_for_interface(gchar *interface_name)
 {
   return NULL;
 
@@ -280,6 +361,6 @@ gchar * farsight_get_ip_for_interface(gchar *interface_name)
 
 
 #else /* G_OS_WIN32 */
-#error Can\'t use this method for retreiving ip list from OS other than unix or windows
+#error Cannot use this method for retreiving ip list from OS other than unix or windows
 #endif /* G_OS_WIN32 */
 #endif /* G_OS_UNIX */
