@@ -36,6 +36,8 @@
 # include <arpa/inet.h>
 # include <sys/types.h>
 # include <sys/socket.h>
+# include <netinet/in.h>
+# include <netinet/ip.h>
 # include <netdb.h>
 #else
 # include <winsock2.h>
@@ -235,6 +237,8 @@ farsight_udp_transmitter_prepare (FarsightTransmitter *transmitter)
   struct sockaddr_in address;
   gint sock;
   gint bindresult = -1;
+  int iptos = 0;
+  int soprio = 0;
 
   if (self->priv->prepared)
     return FALSE;
@@ -250,9 +254,13 @@ farsight_udp_transmitter_prepare (FarsightTransmitter *transmitter)
   switch (media_type) {
     case FARSIGHT_MEDIA_TYPE_AUDIO:
       port = DEFAULT_AUDIO_PORT;
+      iptos = IPTOS_LOWDELAY;
+      soprio = 6;  /* SOPRIO_CONVERSATIONAL */
       break;
     case FARSIGHT_MEDIA_TYPE_VIDEO:
       port = DEFAULT_VIDEO_PORT;
+      iptos = IPTOS_THROUGHPUT;
+      soprio = 5;  /* SOPRIO_STREAMING */
       break;
     default:
       port = 1024;
@@ -267,8 +275,21 @@ farsight_udp_transmitter_prepare (FarsightTransmitter *transmitter)
     return FALSE;
   }
 
+  if (iptos) {
+    if (setsockopt(sock, IPPROTO_IP, IP_TOS, &iptos, sizeof(iptos)) < 0) {
+      g_warning("setsockopt(,IPPROTO_IP,IP_TOS,,) failed");
+    }
+  }
+  if (soprio) {
+    if (setsockopt(sock, SOL_SOCKET, SO_PRIORITY,
+                   &soprio, sizeof(soprio)) < 0) {
+      g_warning("setsockopt(,SOL_SOCKET,SO_PRIORITY,,) failed");
+    }
+  }
+
   while (bindresult != 0)
   {
+    memset (&address, 0, sizeof(struct sockaddr_in));
     address.sin_family = AF_INET;
     address.sin_addr.s_addr = INADDR_ANY;
     address.sin_port = htons (port);
@@ -387,6 +408,12 @@ farsight_udp_transmitter_dispose (GObject *object)
     self->priv->stun_ioc = NULL;
   }
 
+  /* Close the socket since the 'closefd' property is set to FALSE
+     on the udpsrc/udpsink, we have to close it ourself */
+  if (self->priv->local_socket != -1) {
+    close (self->priv->local_socket);
+  }
+
   self->priv->disposed = TRUE;
 
   /* chain up to parent */
@@ -427,6 +454,9 @@ farsight_udp_transmitter_configure_source (FarsightUDPTransmitter *self)
     g_object_set (G_OBJECT(self->priv->gst_src), "sockfd",
         self->priv->local_socket, NULL);
 
+    g_object_set (G_OBJECT(self->priv->gst_src), "closefd",
+        FALSE, NULL);
+
     farsight_transmitter_signal_connection_state_changed (
         FARSIGHT_TRANSMITTER (self),
         FARSIGHT_TRANSMITTER_STATE_CONNECTED);
@@ -458,12 +488,18 @@ farsight_udp_transmitter_create_sink (FarsightUDPTransmitter *self)
 static void
 farsight_udp_transmitter_configure_sink (FarsightUDPTransmitter *self)
 {
-  g_object_set (G_OBJECT(self->priv->gst_sink), "sync", FALSE, NULL);
+  g_object_set (G_OBJECT(self->priv->gst_sink),
+      "sync", FALSE,
+      "preroll-queue-len", 1,
+      NULL);
 
   if (self->priv->local_socket != -1)
   {
     g_object_set (G_OBJECT(self->priv->gst_sink), "sockfd",
         self->priv->local_socket, NULL);
+
+    g_object_set (G_OBJECT(self->priv->gst_sink), "closefd",
+        FALSE, NULL);
   }
 }
 
