@@ -134,7 +134,7 @@ state_changed (FarsightStream * stream,
       farsight_stream_signal_native_candidates_prepared (stream);
 
  //     gst_element_set_state (pipeline, GST_STATE_PLAYING);
-      farsight_stream_start (stream);
+      //farsight_stream_start (stream);
       break;
   }
 }
@@ -142,9 +142,10 @@ state_changed (FarsightStream * stream,
 void
 setup_send (gchar * host, gint port)
 {
-  send_sock = socket (AF_INET, SOCK_DGRAM, 0);
   struct hostent *rx_addr = gethostbyname (host);
 
+  send_sock = socket (AF_INET, SOCK_DGRAM, 0);
+
   serv_addr.sin_family = AF_INET;
   bcopy (rx_addr->h_addr, &serv_addr.sin_addr, rx_addr->h_length);
 
@@ -155,10 +156,10 @@ GIOChannel *
 setup_recv (gint port)
 {
   int sockfd = socket (AF_INET, SOCK_DGRAM, 0);
-  g_message (G_STRFUNC);
-
   struct sockaddr_in dest_addr;
 
+  g_message (G_STRFUNC);
+
   bzero (&dest_addr, sizeof (dest_addr));
   dest_addr.sin_family = AF_INET;
   dest_addr.sin_addr.s_addr = INADDR_ANY;
@@ -225,10 +226,10 @@ do_handshake(gint sockfd)
   gint type;
   socklen_t fromlen;
   struct sockaddr_in from_addr;
+  gchar buf[1500] = { 0 };
 
   send_ready_byte();
   /* wait for reply */
-  gchar buf[1500] = { 0 };
   fromlen = sizeof (struct sockaddr_in);
 
   g_message ("waiting for ready byte");
@@ -312,6 +313,8 @@ add_remote_codec (FarsightStream *stream, gint pt, gchar *encoding_name,
   static GList *remote_codecs_audio = NULL;
   static GList *remote_codecs_video = NULL;
   GList *lp = NULL;
+  FarsightCodec *codec;
+
   if (g_ascii_strcasecmp (encoding_name, "LAST") == 0)
   {
     if (media_type == FARSIGHT_MEDIA_TYPE_AUDIO)
@@ -325,7 +328,7 @@ add_remote_codec (FarsightStream *stream, gint pt, gchar *encoding_name,
     return;
   }
 
-  FarsightCodec *codec = g_new0 (FarsightCodec, 1);
+  codec = g_new0 (FarsightCodec, 1);
 
   codec->id = pt;
   codec->encoding_name = strdup (encoding_name);
@@ -359,11 +362,14 @@ static void
 add_remote_candidate (FarsightStream * stream, gchar * id, gchar * ip,
     gint port, gchar * username, gchar * password)
 {
+  FarsightTransportInfo *trans;
+  GList *candidate_glist = NULL;
+
   //g_print(">>> Adding remote candidate: %s\n", id);
   g_return_if_fail (stream != NULL);
 
   /* let's create our candidate from ip:port given on command line */
-  FarsightTransportInfo *trans = g_new0 (FarsightTransportInfo, 1);
+  trans = g_new0 (FarsightTransportInfo, 1);
 
   trans->candidate_id = g_strdup (id);
   trans->component = 1;
@@ -377,8 +383,6 @@ add_remote_candidate (FarsightStream * stream, gchar * id, gchar * ip,
   trans->username = g_strdup (username);
   trans->password = g_strdup (password);
 
-  GList *candidate_glist = NULL;
-
   candidate_glist = g_list_append (candidate_glist, trans);
 
   farsight_stream_add_remote_candidate (stream, candidate_glist);
@@ -545,7 +549,6 @@ replace_audio_sink (gpointer data)
 }
 */
 
-/*
 static gboolean
 stop_stream (gpointer data)
 {
@@ -555,7 +558,6 @@ stop_stream (gpointer data)
 
   return FALSE;
 }
-*/
 
 /*
 static gboolean
@@ -592,11 +594,12 @@ typedef struct {
   GstElement *tee;
 } ChangePreviewOf;
 
-#if 0
 static gboolean
 change_preview_window (gpointer data)
 {
   ChangePreviewOf *prev_struct = (ChangePreviewOf *)data;
+  GstElement *preview_bin;
+  ChangePreviewOf *nprev_struct;
 
   gst_element_set_state (pipeline, GST_STATE_PAUSED);
 
@@ -605,7 +608,7 @@ change_preview_window (gpointer data)
   gst_element_set_state (prev_struct->sink, GST_STATE_NULL);
   gst_bin_remove (GST_BIN (pipeline), prev_struct->sink);
 
-  GstElement *preview_bin = gst_parse_bin_from_description
+  preview_bin = gst_parse_bin_from_description
     ("ffmpegcolorspace ! videoscale ! ximagesink sync=FALSE",
      TRUE, NULL);
   gst_bin_add (GST_BIN (pipeline), preview_bin);
@@ -614,20 +617,16 @@ change_preview_window (gpointer data)
 
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
 
-
-  /*
-  ChangePreviewOf *nprev_struct = g_new0 (ChangePreviewOf, 1);
+  nprev_struct = g_new0 (ChangePreviewOf, 1);
 
   nprev_struct->tee = prev_struct->tee;
   nprev_struct->sink = preview_bin;
 
   g_timeout_add (3000, change_preview_window, nprev_struct);
-  */
 
   g_free (prev_struct);
   return FALSE;
 }
-#endif
 
 int
 main (int argc, char **argv)
@@ -635,6 +634,12 @@ main (int argc, char **argv)
   char *sinktype;
   GIOChannel *recv_chan;
   gint mode;
+  GstBus *pipe_bus;
+  FarsightSession *session;
+  GstElement *alsasrc = NULL, *alsasink = NULL;
+  GstElement *videosink = NULL;
+  GstElement *tee = NULL;
+  /*GstElement *fakesink = NULL; */
 
   if (argc != 4 && argc != 5 && argc != 6)
   {
@@ -651,11 +656,8 @@ main (int argc, char **argv)
     mode = MODE_DUPLEX;
   }
 
-
   g_debug ("argc: %d, xid=%s", argc, argv[5]);
 
-  GstBus *pipe_bus;
-
   g_type_init ();
   gst_init (&argc, &argv);
 
@@ -676,17 +678,10 @@ main (int argc, char **argv)
 
   g_io_add_watch (recv_chan, G_IO_IN | G_IO_PRI, receive_loop, NULL);
 
-  FarsightSession *session;
-
   session = setup_rtp_session ();
 
   /* it's better to set the active codec before the remote_codecs to avoid a
    * send pipeline change from the start */
-  GstElement *alsasrc = NULL, *alsasink = NULL;
-  GstElement *videosink = NULL;
-  GstElement *tee = NULL;
-  /*GstElement *fakesink = NULL;
-  */
   if (mode == MODE_AUDIO || mode == MODE_DUPLEX)
   {
 
@@ -705,8 +700,6 @@ main (int argc, char **argv)
     //gst_element_link (alsasrc, tee);
     //gst_element_link_filtered (tee, fakesink, prev_caps);
     //gst_element_link (tee, queue);
-    //
-    gst_bin_add (GST_BIN (pipeline), alsasink);
 
     g_object_set (G_OBJECT (alsasink), "sync", FALSE, NULL);
     g_object_set (G_OBJECT (alsasink), "latency-time", G_GINT64_CONSTANT (20000),
@@ -726,6 +719,8 @@ main (int argc, char **argv)
                *glimagesink;
     GstPad *pad;
     GstElement *fakesink;
+    ChangePreviewOf *prev_struct;
+    GstElement *preview_bin;
 
     GstCaps *src_filter = gst_caps_new_simple ("video/x-raw-yuv", "width",
         G_TYPE_INT, 352, "height", G_TYPE_INT, 288, "framerate",
@@ -738,8 +733,8 @@ main (int argc, char **argv)
     gst_bin_add_many (GST_BIN (pipeline), videosrc, tee, NULL);
     gst_element_link (videosrc, tee);
 
-    ChangePreviewOf *prev_struct = g_new0 (ChangePreviewOf, 1);
-    GstElement *preview_bin = gst_parse_bin_from_description
+    prev_struct = g_new0 (ChangePreviewOf, 1);
+    preview_bin = gst_parse_bin_from_description
       ("ffmpegcolorspace ! videoscale ! ximagesink sync=FALSE",
        TRUE, NULL);
     gst_bin_add (GST_BIN (pipeline), preview_bin);
@@ -752,7 +747,7 @@ main (int argc, char **argv)
     prev_struct->sink = preview_bin;
     prev_struct->tee = tee;
 
-    //g_timeout_add (6000, change_preview_window, prev_struct);
+    g_timeout_add (3000, change_preview_window, prev_struct);
 
     sinktype = getenv ("FS_TEST_VIDEO_SINK");
 
@@ -803,15 +798,14 @@ main (int argc, char **argv)
 
     //farsight_stream_set_source_filter (video_stream, src_filter);
     gst_caps_unref (src_filter);
-    gst_bin_add (GST_BIN (pipeline), videosink);
 
     /* let's connect the the prepare-xwindow-id bus message sent by xvimagesink */
     if (argc == 6)
     {
-      g_debug ("setting up xoverlay bus callback");
       GstBus *bus;
       GstElement *pipeline = farsight_stream_get_pipeline (video_stream);
       gulong xid = atol (argv[5]);
+      g_debug ("setting up xoverlay bus callback");
       bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
       gst_bus_set_sync_handler (bus, (GstBusSyncHandler) set_xoverlay, &xid);
     }
@@ -819,7 +813,7 @@ main (int argc, char **argv)
 
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
 
- // sleep (3);
+  //sleep (3);
 
   if (mode == MODE_AUDIO || mode == MODE_DUPLEX)
   {
@@ -831,20 +825,18 @@ main (int argc, char **argv)
     video_stream = setup_rtp_stream (session, FARSIGHT_MEDIA_TYPE_VIDEO);
   }
 
-  g_debug ("ok next");
-
   if (audio_stream)
   {
     farsight_stream_set_active_codec (audio_stream, 8);
     farsight_stream_set_source (audio_stream, alsasrc);
     farsight_stream_set_sink (audio_stream, alsasink);
-    //g_timeout_add (5000, stop_stream, audio_stream);
+    g_timeout_add (100000, stop_stream, audio_stream);
   }
   if (video_stream)
   {
     farsight_stream_set_sink(video_stream, videosink);
     farsight_stream_set_source(video_stream, tee);
-    //g_timeout_add (5000, stop_stream, video_stream);
+    g_timeout_add (100000, stop_stream, video_stream);
   }
 
   //g_timeout_add (5000, replace_audio_sink, NULL);
@@ -907,17 +899,11 @@ setup_rtp_stream (FarsightSession * session, FarsightMediaType type)
         codec->clock_rate);
   }
 
-  g_debug ("wazap");
-
   send_codecs (possible_codecs);
 
-  g_debug ("wazap");
-
   farsight_stream_set_pipeline (stream, (GstElement *)pipeline);
 
-  g_debug ("wazap");
   farsight_stream_prepare_transports (stream);
-  g_debug ("wazap");
 
   return stream;
 }
