@@ -99,6 +99,7 @@ state_changed (FarsightStream *stream,
 
 FarsightSession *setup_rtp_session();
 FarsightStream *setup_rtp_stream(FarsightSession *session);
+gboolean print_stats (FarsightStream *stream);
 
 FarsightCodecPreference codec_pref_list[] = {
   { "AMR", 8000 },
@@ -201,6 +202,8 @@ int main(int argc, char **argv)
 
     farsight_stream_start(stream1);
 
+    g_timeout_add (1000, (GSourceFunc) print_stats, stream1);
+
     g_main_loop_run(mainloop);
     return 0;
 }
@@ -265,3 +268,39 @@ FarsightStream *setup_rtp_stream(FarsightSession *session)
 
     return stream;
 }
+
+gboolean print_stats (FarsightStream *stream)
+{
+  gboolean ret;
+  guint64 total_packets;
+  guint64 late_packets;
+  guint64 duplicate_packets;
+  guint   fill_level;
+  guint64 times_overrun;
+  guint64 times_underrun;
+
+  ret = farsight_stream_get_jb_statistics (stream,
+      &total_packets,
+      &late_packets,
+      &duplicate_packets,
+      &fill_level,
+      &times_overrun,
+      &times_underrun);
+
+#ifdef G_GUINT64_FORMAT
+  if (ret)
+    g_print ("Stream stats\n"
+      "Packets: total: %"G_GUINT64_FORMAT" late: %"G_GUINT64_FORMAT" "
+      "dupes: %"G_GUINT64_FORMAT"\n"
+      "fill-level: %u underrun:%"G_GUINT64_FORMAT" "
+      "overrun: %"G_GUINT64_FORMAT"\n",
+      total_packets, late_packets, duplicate_packets, fill_level,
+      times_overrun, times_underrun);
+  else
+    g_print ("No stats\n");
+#else
+    #warning G_GUINT64_FORMAT unavailable on your plateform
+#endif
+
+  return TRUE;
+}
