@@ -110,14 +110,19 @@ have_keypress (GIOChannel *ioc, GIOCondition cond, gpointer data)
   FarsightStream *stream = FARSIGHT_STREAM (data);
   gchar c;
   gsize size;
-  /*  guint8 ev = 0;
+
+#if 1
+  guint8 ev = 0;
   static gboolean sending = FALSE;
-  */
+#endif
+
   g_io_channel_read_chars (ioc, &c, 1, &size, NULL);
   if (size != 1)
     return TRUE;
 
-  /*  if (c >= '0' && c <= '9') {
+#if 1
+
+  if (c >= '0' && c <= '9') {
     ev = c -'0';
   } else if (c < ' ') {
     return TRUE;
@@ -139,15 +144,16 @@ have_keypress (GIOChannel *ioc, GIOCondition cond, gpointer data)
 
   if (sending) {
     g_print ("Stopping DTMF rv:%d\n",
-        farsight_stream_stop_telephony_event_full (stream, method));
+        farsight_stream_stop_telephony_event_full (stream, dtmf_method));
     sending = FALSE;
   } else {
     g_print ("Starting DTMF %d, rv:%d\n", ev,
         farsight_stream_start_telephony_event_full (stream, ev, 5,
             dtmf_method));
     sending = TRUE;
-  }*/
+  }
 
+#else
 
   farsight_stream_start_telephony_event_full (stream, FARSIGHT_DTMF_EVENT_0, 30, dtmf_method);
   farsight_stream_stop_telephony_event_full (stream, dtmf_method);
@@ -183,6 +189,7 @@ have_keypress (GIOChannel *ioc, GIOCondition cond, gpointer data)
   farsight_stream_start_telephony_event_full (stream, FARSIGHT_DTMF_EVENT_4, 20, dtmf_method);
   farsight_stream_stop_telephony_event_full (stream, dtmf_method);
 
+#endif
 
   return TRUE;
 }
@@ -220,7 +227,6 @@ int main(int argc, char **argv)
         farsight_stream_get_local_codecs(stream1));
     
     farsight_stream_set_remote_codecs(stream1, local_codecs);
-    farsight_codec_list_destroy (local_codecs);
 
     /* let's create our candidate from ip:port given on command line */
     trans = g_new0 (FarsightTransportInfo,1);
